Author: pburba
Date: Mon Nov 5 15:27:24 2012
New Revision: 1405834
URL: http://svn.apache.org/viewvc?rev=1405834&view=rev
Log:
Rename the new ignores and auto-props inheritable properties, see
http://svn.haxx.se/dev/archive-2012-11/0002.shtml
* subversion/include/svn_props.h
* subversion/libsvn_client/add.c
* subversion/libsvn_client/client.h
* subversion/libsvn_client/commit.c
* subversion/tests/cmdline/autoprop_tests.py
* subversion/tests/cmdline/import_tests.py
* subversion/tests/cmdline/prop_tests.py
* subversion/tests/cmdline/svntest/main.py
"svn:inheritable-auto-props" --> "svn:auto-props".
"svn:inheritable-ignores" --> "svn:global-ignores"
Modified:
subversion/trunk/subversion/include/svn_props.h
subversion/trunk/subversion/libsvn_client/add.c
subversion/trunk/subversion/libsvn_client/client.h
subversion/trunk/subversion/libsvn_client/commit.c
subversion/trunk/subversion/tests/cmdline/autoprop_tests.py
subversion/trunk/subversion/tests/cmdline/import_tests.py
subversion/trunk/subversion/tests/cmdline/prop_tests.py
subversion/trunk/subversion/tests/cmdline/svntest/main.py
Modified: subversion/trunk/subversion/include/svn_props.h
URL:
http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_props.h?rev=1405834&r1=1405833&r2=1405834&view=diff
==============================================================================
--- subversion/trunk/subversion/include/svn_props.h (original)
+++ subversion/trunk/subversion/include/svn_props.h Mon Nov 5 15:27:24 2012
@@ -384,14 +384,11 @@ svn_prop_name_is_valid(const char *prop_
*/
#define SVN_PROP_MERGEINFO SVN_PROP_PREFIX "mergeinfo"
-/** Prefix for all Subersion inhertiable properties. */
-#define SVN_PROP_INHERITABLE_PREFIX SVN_PROP_PREFIX "inheritable-"
-
/** Property used to record inheritable configuration auto-props. */
-#define SVN_PROP_INHERITABLE_AUTO_PROPS SVN_PROP_INHERITABLE_PREFIX
"auto-props"
+#define SVN_PROP_INHERITABLE_AUTO_PROPS SVN_PROP_PREFIX "auto-props"
/** Property used to record inheritable configuration ignores. */
-#define SVN_PROP_INHERITABLE_IGNORES SVN_PROP_INHERITABLE_PREFIX "ignores"
+#define SVN_PROP_INHERITABLE_IGNORES SVN_PROP_PREFIX "global-ignores"
/** Meta-data properties.
*
Modified: subversion/trunk/subversion/libsvn_client/add.c
URL:
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/add.c?rev=1405834&r1=1405833&r2=1405834&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/add.c (original)
+++ subversion/trunk/subversion/libsvn_client/add.c Mon Nov 5 15:27:24 2012
@@ -292,7 +292,7 @@ add_file(const char *local_abspath,
apr_hash_t *file_autoprops;
/* Get automatic properties */
- /* Grab the inherited svn:inheritable-auto-props and config file
+ /* Grab the inherited svn:auto-props and config file
auto-props for this file if we haven't already got them
when iterating over the file's unversioned parents. */
if (autoprops == NULL)
@@ -380,12 +380,12 @@ add_file(const char *local_abspath,
* if necessary.
*
* If not NULL, *CONFIG_AUTOPROPS is a hash representing the config file and
- * svn:inheritable-auto-props autoprops which apply to DIR_ABSPATH. It maps
+ * svn:auto-props autoprops which apply to DIR_ABSPATH. It maps
* const char * file patterns to another hash which maps const char *
* property names to const char *property values. If *CONFIG_AUTOPROPS is
* NULL and DIR_ABSPATH is unversioned, then this function will populate
* *CONFIG_AUTOPROPS (allocated in RESULT_POOL) using DIR_ABSPATH's nearest
- * versioned parent to determine the svn:inheritable-auto-props which
DIR_ABSPATH
+ * versioned parent to determine the svn:auto-props which DIR_ABSPATH
* will inherit once added.
*
* If IGNORES is not NULL, then it is an array of const char * ignore patterns
@@ -452,9 +452,9 @@ add_dir_recursive(const char *dir_abspat
/* For the root of any unversioned subtree, get some or all of the
following:
- 1) Explicit and inherited svn:inheritable-auto-props properties on
+ 1) Explicit and inherited svn:auto-props properties on
DIR_ABSPATH
- 2) Explicit and inherited svn:inheritabled-ignores properties on
+ 2) Explicit and inherited svn:global-ignores properties on
DIR_ABSPATH
3) auto-props from the CTX->CONFIG hash */
if (!entry_exists && *config_autoprops == NULL)
@@ -537,7 +537,7 @@ add_dir_recursive(const char *dir_abspat
}
/* This structure is used as baton for collecting the config entries
- in the auto-props section and any inherited svn:inheritable-auto-props
+ in the auto-props section and any inherited svn:auto-props
properties.
*/
typedef struct collect_auto_props_baton_t
@@ -702,7 +702,7 @@ svn_client__get_all_auto_props(apr_hash_
/* Are "traditional" auto-props enabled? If so grab them from the
config. This is our starting set auto-props, which may be overriden
- by svn:inheritable-auto-props. */
+ by svn:auto-props. */
SVN_ERR(svn_config_get_bool(cfg, &use_autoprops,
SVN_CONFIG_SECTION_MISCELLANY,
SVN_CONFIG_OPTION_ENABLE_AUTO_PROPS, FALSE));
@@ -781,7 +781,7 @@ svn_client__get_all_auto_props(apr_hash_
config_auto_prop_pattern = svn_stringbuf_create_empty(iterpool);
config_auto_prop_val = svn_stringbuf_create_empty(iterpool);
- /* Parse svn:inheritable-auto-props value. */
+ /* Parse svn:auto-props value. */
while (*ch != '\0')
{
svn_stringbuf_setempty(config_auto_prop_pattern);
Modified: subversion/trunk/subversion/libsvn_client/client.h
URL:
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/client.h?rev=1405834&r1=1405833&r2=1405834&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/commit.c (original)
+++ subversion/trunk/subversion/libsvn_client/commit.c Mon Nov 5 15:27:24 2012
@@ -77,7 +77,7 @@ typedef struct import_ctx_t
svn_magic__cookie_t *magic_cookie;
/* Collection of all possible configuration file dictated auto-props and
- svn:inheritable-auto-props. A hash mapping const char * file patterns to
a
+ svn:auto-props. A hash mapping const char * file patterns to a
second hash which maps const char * property names to const char *
property values. Properties which don't have a value, e.g.
svn:executable,
simply map the property name to an empty string. */
@@ -613,7 +613,7 @@ import_dir(const svn_delta_editor_t *edi
* the import (values are unused).
*
* AUTOPROPS is hash of all config file autoprops and
- * svn:inheritable-auto-props inherited by the import target, see the
+ * svn:auto-props inherited by the import target, see the
* IMPORT_CTX member of the same name.
*
* LOCAL_IGNORES is an array of const char * ignore patterns which
@@ -622,7 +622,7 @@ import_dir(const svn_delta_editor_t *edi
* target should be ignored and not imported.
*
* MANDATORY_IGNORES is an array of const char * ignore patterns which
- * correspond to the svn:inheritable-ignores properties (if any) set on
+ * correspond to the svn:global-ignores properties (if any) set on
* the root of the repository target or inherited by it.
*
* If NO_IGNORE is FALSE, don't import files or directories that match
@@ -1029,7 +1029,7 @@ svn_client_import5(const char *path,
commit_baton, NULL, TRUE,
scratch_pool));
- /* Get inherited svn:inheritable-auto-props, svn:inheritable-ignores, and
+ /* Get inherited svn:auto-props, svn:global-ignores, and
svn:ignores for the location we are importing to. */
SVN_ERR(svn_client__get_all_auto_props(&autoprops, url, ctx,
scratch_pool, iterpool));
Modified: subversion/trunk/subversion/tests/cmdline/autoprop_tests.py
URL:
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/autoprop_tests.py?rev=1405834&r1=1405833&r2=1405834&view=diff
==============================================================================
--- subversion/trunk/subversion/tests/cmdline/autoprop_tests.py (original)
+++ subversion/trunk/subversion/tests/cmdline/autoprop_tests.py Mon Nov 5
15:27:24 2012
@@ -385,7 +385,7 @@ def check_inheritable_autoprops(sbox, au
#----------------------------------------------------------------------
def inheritable_autoprops_test(sbox, cmd, cfgenable, clienable, subdir,
do_import_or_add=True):
- """configurable autoprops and svn:inheritable-auto-props test.
+ """configurable autoprops and svn:auto-props test.
CMD is the subcommand to test: 'import' or 'add'
if CFGENABLE is true, enable autoprops in the config file, else disable
@@ -438,7 +438,7 @@ def inheritable_autoprops_test(sbox, cmd
else:
files_wc_dir = wc_dir
- # Set differing svn:inheritable-auto-props properties on various
+ # Set differing svn:auto-props properties on various
# directories.
sbox.simple_propset(SVN_PROP_INHERITABLE_AUTOPROPS,
'*.c = svn:eol-style=CRLF\n'
@@ -590,10 +590,10 @@ def svn_prop_inheritable_autoprops_imp_y
inheritable_autoprops_test(sbox, 'import', 1, -1, '')
#----------------------------------------------------------------------
-# Test svn:inheritable-auto-props when 'svn add' targets an already versioned
+# Test svn:auto-props when 'svn add' targets an already versioned
# target.
def svn_prop_inheritable_autoprops_add_versioned_target(sbox):
- "svn:inheritable-auto-props and versioned target"
+ "svn:auto-props and versioned target"
config_dir = inheritable_autoprops_test(sbox, 'add', 1, 0, '', False)
@@ -612,9 +612,9 @@ def svn_prop_inheritable_autoprops_add_v
check_inheritable_autoprops(sbox, True)
#----------------------------------------------------------------------
-# Can't set svn:inheritable-auto-props on files.
+# Can't set svn:auto-props on files.
def svn_prop_inheritable_autoprops_propset_file_target(sbox):
- "svn:inheritable-auto-props can't be set on files"
+ "svn:auto-props can't be set on files"
sbox.build()
svntest.actions.run_and_verify_svn(
@@ -634,7 +634,7 @@ def svn_prop_inheritable_autoprops_unver
foo_path = sbox.ospath('A/D/Z/foo.c')
bar_path = sbox.ospath('A/B/Y/bar.c')
- # Set svn:inheritable-auto-props properties on two directories.
+ # Set svn:auto-props properties on two directories.
svntest.main.run_svn(None, 'ps', SVN_PROP_INHERITABLE_AUTOPROPS,
'*.c=svn:eol-style=CR', sbox.ospath('A/B'))
svntest.main.run_svn(None, 'ps', SVN_PROP_INHERITABLE_AUTOPROPS,
Modified: subversion/trunk/subversion/tests/cmdline/import_tests.py
URL:
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/import_tests.py?rev=1405834&r1=1405833&r2=1405834&view=diff
==============================================================================
--- subversion/trunk/subversion/tests/cmdline/import_tests.py (original)
+++ subversion/trunk/subversion/tests/cmdline/import_tests.py Mon Nov 5
15:27:24 2012
@@ -469,8 +469,8 @@ def import_inherited_ignores(sbox):
# Import the tree to ^/A/B/E.
# We should never see any *.noo paths because those are blocked at the
- # root of the repository by the svn:inheritable-ignores property. Likewise
- # *.doo paths are blocked by the svn:inheritable-ignores on ^/A/B. Nor
+ # root of the repository by the svn:global-ignores property. Likewise
+ # *.doo paths are blocked by the svn:global-ignores on ^/A/B. Nor
# should we see and *.boo or *.goo paths, as those are blocked by the
# global-ignores config. Lastly, ^/A/B/E should not get any *.foo paths
# because of the svn:ignore property on ^/A/B/E, but non-immediate children
@@ -517,7 +517,7 @@ def import_inherited_ignores(sbox):
svntest.actions.run_and_verify_svn(None, expected_output, [], 'up', wc_dir)
# Import the tree to ^/A/B/F with the --no-ignore option.
- # Now only the ignores present in the svn:inheritable-ignores property
+ # Now only the ignores present in the svn:global-ignores property
# should be considered.
svntest.actions.run_and_verify_svn(None, None, [], 'import',
'--config-dir', config_dir,
Modified: subversion/trunk/subversion/tests/cmdline/prop_tests.py
URL:
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/prop_tests.py?rev=1405834&r1=1405833&r2=1405834&view=diff
==============================================================================
--- subversion/trunk/subversion/tests/cmdline/prop_tests.py (original)
+++ subversion/trunk/subversion/tests/cmdline/prop_tests.py Mon Nov 5 15:27:24
2012
@@ -2651,7 +2651,7 @@ def inheritable_ignores(sbox):
os.chdir(saved_wd)
# Now revert and try the add with the --no-ignore flag, only the
- # svn:inheritable-ignores should be enforced.
+ # svn:global-ignores should be enforced.
svntest.actions.run_and_verify_svn(None, None, [], 'revert', wc_dir, '-R')
saved_wd = os.getcwd()
os.chdir(sbox.wc_dir)
Modified: subversion/trunk/subversion/tests/cmdline/svntest/main.py
URL:
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/svntest/main.py?rev=1405834&r1=1405833&r2=1405834&view=diff
==============================================================================
--- subversion/trunk/subversion/tests/cmdline/svntest/main.py (original)
+++ subversion/trunk/subversion/tests/cmdline/svntest/main.py Mon Nov 5
15:27:24 2012
@@ -174,11 +174,11 @@ work_dir = "svn-test-work"
# Constant for the merge info property.
SVN_PROP_MERGEINFO = "svn:mergeinfo"
-# Constant for the inheritabled auto-props property.
-SVN_PROP_INHERITABLE_AUTOPROPS = "svn:inheritable-auto-props"
+# Constant for the inheritable auto-props property.
+SVN_PROP_INHERITABLE_AUTOPROPS = "svn:auto-props"
-# Constant for the inheritabled ignores property.
-SVN_PROP_INHERITABLE_IGNORES = "svn:inheritable-ignores"
+# Constant for the inheritable ignores property.
+SVN_PROP_INHERITABLE_IGNORES = "svn:global-ignores"
# Where we want all the repositories and working copies to live.
# Each test will have its own!
--- subversion/trunk/subversion/libsvn_client/client.h (original)
+++ subversion/trunk/subversion/libsvn_client/client.h Mon Nov 5 15:27:24 2012
@@ -351,11 +351,11 @@ svn_error_t *svn_client__get_paths_auto_
apr_pool_t *scratch_pool);
/* Gather all auto-props from CTX->config (or none if auto-props are
- disabled) and all svn:inheritable-auto-props explicitly set on or inherited
+ disabled) and all svn:auto-props explicitly set on or inherited
by PATH_OR_URL.
If PATH_OR_URL is an unversioned WC path then gather the
- svn:inheritable-auto-props inherited by PATH_OR_URL's nearest versioned
+ svn:auto-props inherited by PATH_OR_URL's nearest versioned
parent.
If PATH_OR_URL is a URL ask for the properties @HEAD, if it is a WC
@@ -366,10 +366,10 @@ svn_error_t *svn_client__get_paths_auto_
names to const char *property values.
If a given property name exists for the same pattern in both the config
- file and in an a svn:inheritable-auto-props property, the latter overrides
the
+ file and in an a svn:auto-props property, the latter overrides the
former. If a given property name exists for the same pattern in two
- different inherited svn:inheritable-auto-props, then the closer path-wise
- property overrides the more distant. svn:inheritable-auto-props explicitly
set
+ different inherited svn:auto-props, then the closer path-wise
+ property overrides the more distant. svn:auto-props explicitly set
on PATH_OR_URL have the highest precedence and override inherited props
and config file settings.
@@ -383,7 +383,7 @@ svn_error_t *svn_client__get_all_auto_pr
/* Get a combined list of ignore patterns from CTX->CONFIG, local ignore
patterns on LOCAL_ABSPATH (per the svn:ignore property), and from any
- svn:inheritable-ignores properties set on, or inherited by, LOCAL_ABSPATH.
+ svn:global-ignores properties set on, or inherited by, LOCAL_ABSPATH.
If LOCAL_ABSPATH is unversioned but is located within a valid working copy,
then find its nearest versioned parent path, if any, and return the ignore
patterns for that parent. Return an SVN_ERR_WC_NOT_WORKING_COPY error if
@@ -398,7 +398,7 @@ svn_error_t *svn_client__get_all_ignores
apr_pool_t *result_pool,
apr_pool_t *scratch_pool);
/* Get a list of ignore patterns defined by the svn:inheritable-ignores
properties set on, or inherited by, PATH_OR_URL. Store the collected
patterns as const char * elements in the array *IGNORES. Allocate
*IGNORES and its contents in RESULT_POOL. Use SCRATCH_POOL for
@@ -398,7 +398,7 @@ svn_error_t *svn_client__get_all_ignores
apr_pool_t *result_pool,
apr_pool_t *scratch_pool);
-/* Get a list of ignore patterns defined by the svn:inheritable-ignores
+/* Get a list of ignore patterns defined by the svn:global-ignores
properties set on, or inherited by, PATH_OR_URL. Store the collected
patterns as const char * elements in the array *IGNORES. Allocate
Modified: subversion/trunk/subversion/libsvn_client/commit.c
URL:
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/commit.c?rev=1405834&r1=1405833&r2=1405834&view=diff
==============================================================================